package at.fhooe.mc.magicwand.client.sensors;

import at.fhooe.mc.magicwand.client.exceptions.CompassException;
import at.fhooe.mc.magicwand.client.exceptions.GPSException;

/**
 * @class SensorDataContainer
 * @author Manuela Vogler
 * @brief Encapsulates the GPS and compass data.
 */
public class SensorDataContainer {

    /**
     * The GPSReader used to get the GPS position
     */
    private GPSReader m_gpsReader;

    /**
     * The CompassSocket used to communicate with the Symbian application
     */
    private CompassSocket m_compassSocket;

    /**
     * @fn public SensorDataContainer() throws CompassException
     * @brief Constructs a new SensorDataContainer with a GPSReader and establishes
     * a connection to the Symbian compass application.
     * @throws CompassException if compass connection can't be established or if compass server doesn't send ack
     */
    public SensorDataContainer() throws CompassException{
        m_gpsReader = new GPSReader();
        m_compassSocket = new CompassSocket(8100); //port 8100 used for communication
    }

    /**
     * @fn public void updateData() throws GPSException
     * @brief Calls the GPSReader to update the current position and the compass
     * socket to send a request to the Symbian application in order to get the current compass angle.
     * @throws GPSException if GPS data is not available
     * @throws CompassException if request isn't successfully
     */
    public void updateData() throws CompassException,GPSException{
        try {
            m_gpsReader.updatePosition();
            m_compassSocket.sendRequest();
        } catch (CompassException _e){
            throw new CompassException ("Compass-data not available");
        } catch (Exception _e) { //exception occured in gpsreader
                throw new GPSException("GPS-data not available");
        }
    }

    /**
     * @fn public double getLatitude()
     * @brief Returns the current latitude.
     * @return The latitude
     */
    public double getLatitude(){
        return m_gpsReader.getLatitude();
    }

    /**
     * @fn public double getLongitude()
     * @brief Returns the current longitude.
     * @return The longitude
     */
    public double getLongitude(){
        return m_gpsReader.getLongitude();
    }


    /**
     * @fn public void close() throws CompassException()
     * @brief Calls the compass socket to send a close message to the Symbian application and close the connection.
     * @throws CompassException if close message can't be sent or connection can't be closed or if server doesn't send ack
     */
    public void close() throws CompassException{
        m_compassSocket.close();
    }

    /**
     * @fn public String getAngle()
     * @brief Returns the current compass angle relative to the north.
     * @return String with the current angle
     */
    public String getAngle(){
        return m_compassSocket.getAngle();
    }

    /**
     * @fn public void set_receives(boolean _receive)
     * @brief sets receiving active or inactive
     * @param _receive set receiving active or inactive
     */
    public void set_receive(boolean _receive) {
        m_compassSocket.setM_receive(_receive);
    }

}
